﻿-- SxBagScale 0.6
-- Author: shiftear
-- Latest version on http://www.wowinterface.com
-- 6 December 2010


-- Description:
--    Scales your default interface bags, I keep mine around 0.85
--	  with no UI scale active.
-- Usage example:
--    /bagscale 0.85
--
-- Change is not immediate, you must close and reopen your bags to see it.

local SxBagScaleDefaults = {
	verbose			= false,
	defaultscale	= 1,
	minscale 		= 0.1,
	maxscale 		= 2
}

-- set to false to disable auto opening on that event
local SxOpenEvents = {
	GUILDBANKFRAME_OPENED = true,
	BANKFRAME_OPENED = true,
	FORGE_MASTER_OPENED = true,
	MAIL_SHOW = true,
	MERCHANT_SHOW = true,
	AUCTION_HOUSE_SHOW = true,
	TRADE_SHOW = true,
	TRADE_SKILL_SHOW = true,
}

local SxCloseEvents = {
	GUILDBANKFRAME_CLOSED = true,
	BANKFRAME_CLOSED = true,
	AUCTION_HOUSE_CLOSED = true,
	FORGE_MASTER_CLOSED = true,
	MAIL_CLOSED = true,
	MERCHANT_CLOSED = true,
	TRADE_CLOSED = true,
	TRADE_SKILL_CLOSE = true,
}

local frame=CreateFrame("FRAME")
frame:RegisterEvent("ADDON_LOADED")
frame:RegisterEvent("PLAYER_LOGOUT")

local NUMBAGS=_G["NUM_BAG_SLOTS"]
local NUMBANKBAGS=_G["NUM_BANKBAGSLOTS"]


function frame:OnLoad(event, arg1)
	if event == "ADDON_LOADED"  and arg1 == "SxBagScale" then
		SxBagScalePrint("|cff003399SxBagScale|r loaded.", true)
		
		SxBagScaleCheck(SxBagScale);
		
		SLASH_SXBAGSCALE1 = "/bagscale"
		SlashCmdList["SXBAGSCALE"] = SxBagScaleCmdHandler;
		
		-- register open events
		for openevent, enabled in pairs(SxOpenEvents) do
			frame:RegisterEvent(openevent)
		end
		
		-- register close events
		for closeevent, enabled in pairs(SxCloseEvents) do
			frame:RegisterEvent(closeevent)
		end
		
	elseif SxOpenEvents[event] then
		SxOpenAllBags(true)
		
	elseif SxCloseEvents[event] then
		SxCloseAllBags()
	end
end

frame:SetScript("OnEvent",frame.OnLoad)

-- bags open function
function SxOpenAllBags()
	for i = 0,(_G["NUM_BAG_SLOTS"] + _G["NUM_BANKBAGSLOTS"]) do
			OpenBag(i);
	end
	-- OpenAllBags(true)
	ContainerFrame1.backpackWasOpen = 1
end

-- bags close function
function SxCloseAllBags()
	ContainerFrame1.backpackWasOpen = nil
	CloseAllBags()
end

-- slash handler
function SxBagScaleCmdHandler(msg)
	local value = tonumber(msg)
	
	if (not value) then
		local current;
		if SxBagScale then
			current = SxBagScale
		else
			current = SxBagScaleDefaults.defaultscale
		end
		
		SxBagScalePrint("|cff003399SxBagScale|r usage: /bagscale number, current scale is "..current, true)
	else
		SxBagScaleCheck(value);
	end
end

-- bag scaling
function SxBagUpdateScale()

	for i=1, 13 do
		local frame = _G["ContainerFrame"..i]
		frame:SetScale(SxBagScale)
	end
	
	if(GuildBankFrame and GuildBankFrame:IsShown()) then
		GuildBankFrame:SetScale(SxBagScale)
	end
	
	if(BankFrame and  BankFrame:IsShown())  then
		BankFrame:SetScale(SxBagScale)
	end
end

function SxBagScaleCheck(scale)
	if(not scale or (scale < SxBagScaleDefaults.minscale or scale > SxBagScaleDefaults.maxscale)) then
		SxBagScalePrint("|cff003399SxBagScale|r: bag scale out of bounds or not initialized, resetting to defaults.", true)
		SxBagScale = SxBagScaleDefaults.defaultscale
	else
		SxBagScale = scale
		SxBagScalePrint("|cff003399SxBagScale|r: bag scale set to "..scale, true)
		SxBagUpdateScale()
	end
end

function SxBagScalePrint(message, force)
	if(SxBagScaleDefaults.verbose or force) then
		DEFAULT_CHAT_FRAME:AddMessage(message)
	end
end

hooksecurefunc("updateContainerFrameAnchors",
	SxBagUpdateScale
)
